@@ -20,16 +20,20 @@ from pynfogen.nfo import NFO
 @click.option("-tmdb", type=str, default=None, help="TMDB ID (including 'tv/' or 'movie/').")
 @click.option("-tvdb", type=int, default=None, help="TVDB ID ('73244' not 'the-office-us').")
 @click.option("-S", "--source", type=str, default=None, help="Source information.")
-@click.option("-N", "--notes", type=str, default=None, help="Notes/special information.")
+@click.option("-N", "--note", type=str, default=None, help="Notes/special information.")
 @click.option("-P", "--preview", type=str, default=None, help="Preview information, typically an URL.")
 @click.pass_obj
 def generate(obj, file: str, template: str, artwork: str = None, season: str = None, episode: Tuple[int, str] = None,
-             imdb: str = None, tmdb: str = None, tvdb: int = None, source: str = None, notes: str = None,
+             imdb: str = None, tmdb: str = None, tvdb: int = None, source: str = None, note: str = None,
              preview: str = None):
     """
     Generate an NFO for a file.
-    It's recommended to specify both -e and -et if not a season.
-    Whether the values get used is up to the template to decide.
+
+    \b
+    The content type is detected based on which values are set.
+    - Movie: Neither -s nor -e is set.
+    - Season: -s is set and -e is not.
+    - Episode: -e is set. -s can be set or not though it's recommended.
     """
     if season.isdigit():
         season = int(season)
@@ -46,7 +50,7 @@ def generate(obj, file: str, template: str, artwork: str = None, season: str = N
                     tmdb=tmdb,
                     tvdb=tvdb,
                     source=source,
-                    notes=notes,
+                    note=note,
                     preview=preview,
                     **yaml.load(f, Loader=yaml.FullLoader)
                 )
